db
==

In this module there are all the database setups and models used by the weatherDB package, you shouldn't need to use them directly.

models
------

Those are the database models

.. automodule:: weatherDB.db.models

base models
^^^^^^^^^^^

.. autoclass:: weatherDB.db.models.ModelBase

.. autoclass:: weatherDB.db.models.MetaBase

.. autoclass:: weatherDB.db.models.MetaBaseQC



